@@ -230,6 +230,12 @@ class Colony:
         resp = self.session.delete(url=method_url)
         GatewayUtils.handle_response(response=resp, return_codes=[200])
 
+    def unregister_cloud_account(self, cloud_account_name: str):
+        method_url = self._api_root.settings.cloud_accounts()
+        body = {"cloud_account_name": cloud_account_name}
+        resp = self.session.delete(url=method_url, json=body)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
     def unregister_azure_account(self, cloud_account_name: str):
         method_url = self._api_root.settings.azure_cloud_account_by_name(
             cloud_account_name
@@ -506,6 +512,7 @@ class Colony:
             if retry:
                 time.sleep(30)  # need to make sure that the next call will not use the cached timedout error
                 self.end_sandbox(sandbox_id, False)
+                return
             raise TimeoutError()
 
         GatewayUtils.handle_response(response=resp, return_codes=[202])
